@@ -1,14 +1,12 @@
-package Hash::Util::FieldHash::Compat;
-BEGIN {
-  $Hash::Util::FieldHash::Compat::AUTHORITY = 'cpan:NUFFIN';
-}
-# git description: v0.06-2-g17d9df6
-$Hash::Util::FieldHash::Compat::VERSION = '0.07';
+package Hash::Util::FieldHash::Compat; # git description: v0.08-12-gc264723
 # ABSTRACT: Use Hash::Util::FieldHash or ties, depending on availability
+# KEYWORDS: fields hashes fieldhash backwards compatibility backcompat tie
 
 use strict;
 use warnings;
 
+our $VERSION = '0.09';
+
 use constant REAL_FIELDHASH => do { local $@; local $SIG{__DIE__}; eval { require Hash::Util::FieldHash } };
 
 BEGIN {
@@ -48,7 +46,7 @@ Hash::Util::FieldHash::Compat - Use Hash::Util::FieldHash or ties, depending on
 
 =head1 VERSION
 
-version 0.07
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -77,6 +75,12 @@ L<Hash::Util::FieldHash>, L<Tie::RefHash>, L<Tie::RefHash::Weak>.
 
 יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Karen Etheridge
+
+Karen Etheridge <ether@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman).
